You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by da...@apache.org on 2016/08/01 04:31:57 UTC

svn commit: r1754701 [2/13] - in /openoffice/branches/gbuild-reintegration: ./ ext_libraries/apr-util/ ext_libraries/apr/ ext_sources/ main/ main/accessibility/inc/accessibility/standard/ main/autodoc/inc/ary/idl/ main/avmedia/source/framework/ main/ba...

Modified: openoffice/branches/gbuild-reintegration/main/basegfx/source/matrix/b2dhommatrix.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/basegfx/source/matrix/b2dhommatrix.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/basegfx/source/matrix/b2dhommatrix.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/basegfx/source/matrix/b2dhommatrix.cxx Mon Aug  1 04:31:52 2016
@@ -379,7 +379,7 @@ namespace basegfx
 				double fCrossXY(aUnitVecX.cross(aUnitVecY));
 
 				// get rotation by calculating angle of X unit vector relative to (1, 0).
-				// This is before the parallell test following the motto to extract
+				// This is before the parallel test following the motto to extract
 				// as much as possible
 				rRotate = atan2(aUnitVecX.getY(), aUnitVecX.getX());
 
@@ -394,7 +394,7 @@ namespace basegfx
 
 					// unit vectors are parallel, thus not linear independent. No
 					// useful decomposition possible. This should not happen since
-					// the only way to get the unit vectors nearly parallell is
+					// the only way to get the unit vectors nearly parallel is
 					// a very big shearing. Anyways, be prepared for hand-filled
 					// matrices
 					// Eventually used rotations or shears are lost

Modified: openoffice/branches/gbuild-reintegration/main/basegfx/source/polygon/b2dlinegeometry.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/basegfx/source/polygon/b2dlinegeometry.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/basegfx/source/polygon/b2dlinegeometry.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/basegfx/source/polygon/b2dlinegeometry.cxx Mon Aug  1 04:31:52 2016
@@ -875,7 +875,7 @@ namespace basegfx
 
                             if(ORIENTATION_NEUTRAL == aOrientation)
                             {
-                                   // they are parallell or empty; if they are both not zero and point 
+                                   // they are parallel or empty; if they are both not zero and point 
                                    // in opposite direction, a half-circle is needed
                                    if(!aTangentPrev.equalZero() && !aTangentEdge.equalZero())
                                    {

Modified: openoffice/branches/gbuild-reintegration/main/basegfx/source/polygon/b2dpolygonclipper.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/basegfx/source/polygon/b2dpolygonclipper.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/basegfx/source/polygon/b2dpolygonclipper.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/basegfx/source/polygon/b2dpolygonclipper.cxx Mon Aug  1 04:31:52 2016
@@ -234,7 +234,7 @@ namespace basegfx
 
             if(!bInside)
             {
-                // cutting off the outer parts of filled polygons at parallell
+                // cutting off the outer parts of filled polygons at parallel
                 // lines to the axes is only possible for the inner part, not for
                 // the outer part which means cutting a hole into the original polygon.
                 // This is because the inner part is a logical AND-operation of
@@ -334,7 +334,7 @@ namespace basegfx
             else
             {
                 // for details, see comment in clipPolygonOnRange for the "cutting off 
-                // the outer parts of filled polygons at parallell lines" explanations
+                // the outer parts of filled polygons at parallel lines" explanations
         		const B2DPolygon aClip(createPolygonFromRect(rRange));
         		
                 return clipPolyPolygonOnPolyPolygon(rCandidate, B2DPolyPolygon(aClip), bInside, bStroke);

Modified: openoffice/branches/gbuild-reintegration/main/basegfx/source/raster/rasterconvert3d.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/basegfx/source/raster/rasterconvert3d.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/basegfx/source/raster/rasterconvert3d.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/basegfx/source/raster/rasterconvert3d.cxx Mon Aug  1 04:31:52 2016
@@ -293,7 +293,7 @@ namespace basegfx
 		        const sal_uInt32 nYDelta(static_cast<sal_uInt32>(nYEnd - nYStart));
 		        const double fInvYDelta(1.0 / nYDelta);
 
-		        // non-horizontal line, create two parallell entries. These will be sorted by
+		        // non-horizontal line, create two parallel entries. These will be sorted by
 		        // X anyways, so no need to distinguish the case here
 		        maLineEntries.push_back(RasterConversionLineEntry3D(
 			        aStart.getX(), (aEnd.getX() - aStart.getX()) * fInvYDelta,

Modified: openoffice/branches/gbuild-reintegration/main/basic/inc/basic/sbxform.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/basic/inc/basic/sbxform.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/basic/inc/basic/sbxform.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/basic/inc/basic/sbxform.hxx Mon Aug  1 04:31:52 2016
@@ -98,7 +98,7 @@ class SbxBasicFormater {
 	/* Basic command: Format$( number,format-string )
 
 	   Parameter:
-		dNumber		: number to be formated
+		dNumber		: number to be formatted
 		sFormatStrg	: the Format-String, e.g. ###0.0###
 
 	   Return value:

Modified: openoffice/branches/gbuild-reintegration/main/basic/source/basmgr/basmgr.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/basic/source/basmgr/basmgr.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/basic/source/basmgr/basmgr.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/basic/source/basmgr/basmgr.cxx Mon Aug  1 04:31:52 2016
@@ -692,7 +692,7 @@ BasicManager::BasicManager( SotStorage&
         DBG_ASSERT( pStdLib, "Standard-Lib not loaded?" );
         if ( !pStdLib )
         {
-            // Should never happen, but if it happens we wont crash...
+            // Should never happen, but if it happens we won't crash...
             pStdLib = new StarBASIC( NULL, mbDocMgr );
 			BasicLibInfo* pStdLibInfo = pLibs->GetObject( 0 );
 			if ( !pStdLibInfo )

Modified: openoffice/branches/gbuild-reintegration/main/basic/source/comp/loops.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/basic/source/comp/loops.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/basic/source/comp/loops.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/basic/source/comp/loops.cxx Mon Aug  1 04:31:52 2016
@@ -538,7 +538,7 @@ void SbiParser::Resume()
 			{
 				aGen.Gen( _RESUME, 0 );
 				break;
-			} // fall thru
+			} // fall through
 		case SYMBOL:
 			if( MayBeLabel() )
 			{
@@ -546,7 +546,7 @@ void SbiParser::Resume()
 				aGen.Gen( _RESUME, nLbl );
 				Next();
 				break;
-			} // fall thru
+			} // fall through
 		default:
 			Error( SbERR_LABEL_EXPECTED );
 	}

Modified: openoffice/branches/gbuild-reintegration/main/bean/com/sun/star/comp/beans/Wrapper.java
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/bean/com/sun/star/comp/beans/Wrapper.java?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/bean/com/sun/star/comp/beans/Wrapper.java (original)
+++ openoffice/branches/gbuild-reintegration/main/bean/com/sun/star/comp/beans/Wrapper.java Mon Aug  1 04:31:52 2016
@@ -30,7 +30,7 @@ import com.sun.star.uno.UnoRuntime;
  	mode of automatic runtime Java classes to get rid of the need for
 	queryInterface.
 
-	Because its not worth the efford to create a runtime generated wrapper
+	Because it's not worth the effort to create a runtime generated wrapper
 	for this purpose, as it might be for OOo 2.0, you still have to use
 	UnoRuntime.queryInterface() for interfaces which are optional or come
 	from a subclass.  But for non optional interfaces you can already 

Modified: openoffice/branches/gbuild-reintegration/main/beanshell/makefile.mk
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/beanshell/makefile.mk?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/beanshell/makefile.mk (original)
+++ openoffice/branches/gbuild-reintegration/main/beanshell/makefile.mk Mon Aug  1 04:31:52 2016
@@ -44,10 +44,10 @@ all:
 
 # --- Files --------------------------------------------------------
 
-TARFILE_NAME=bsh-2.0b5-src
-TARFILE_MD5=ec1941a74d3ef513c4ce57a9092b74e1
-TARFILE_ROOTDIR=BeanShell-2.0b5
-PATCH_FILES=bsh-2.0b5-src.patch
+TARFILE_NAME=bsh-2.0b6-src
+TARFILE_MD5=beeca87be45ec87d241ddd0e1bad80c1
+TARFILE_ROOTDIR=BeanShell-2.0b6
+PATCH_FILES=bsh-2.0b6-src.patch
 
 ADDITIONAL_FILES=makefile.mk
 

Modified: openoffice/branches/gbuild-reintegration/main/boost/boost_1_55_0.patch
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/boost/boost_1_55_0.patch?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/boost/boost_1_55_0.patch (original)
+++ openoffice/branches/gbuild-reintegration/main/boost/boost_1_55_0.patch Mon Aug  1 04:31:52 2016
@@ -1,5 +1,167 @@
---- misc/boost_1_55_0/boost/unordered/detail/equivalent.hpp	2012-12-05 23:06:57.000000000 +0100
-+++ misc/build/boost_1_55_0/boost/unordered/detail/equivalent.hpp	2014-01-07 10:33:59.550621750 +0100
+diff -ur misc/boost_1_55_0/boost/asio/ssl/impl/context.ipp misc/build/boost_1_55_0/boost/asio/ssl/impl/context.ipp
+--- misc/boost_1_55_0/boost/asio/ssl/impl/context.ipp	2013-10-26 16:25:53.000000000 -0700
++++ misc/build/boost_1_55_0/boost/asio/ssl/impl/context.ipp	2016-03-23 01:11:12.425434000 -0700
+@@ -87,6 +87,14 @@
+     handle_ = ::SSL_CTX_new(::SSLv2_server_method());
+     break;
+ #endif // defined(OPENSSL_NO_SSL2)
++#if defined(OPENSSL_NO_SSL3)
++  case context::sslv3:
++  case context::sslv3_client:
++  case context::sslv3_server:
++    boost::asio::detail::throw_error(
++        boost::asio::error::invalid_argument, "context");
++    break;
++#else // defined(OPENSSL_NO_SSL3)
+   case context::sslv3:
+     handle_ = ::SSL_CTX_new(::SSLv3_method());
+     break;
+@@ -96,6 +104,7 @@
+   case context::sslv3_server:
+     handle_ = ::SSL_CTX_new(::SSLv3_server_method());
+     break;
++#endif // defined(OPENSSL_NO_SSL3)
+   case context::tlsv1:
+     handle_ = ::SSL_CTX_new(::TLSv1_method());
+     break;
+diff -ur misc/boost_1_55_0/boost/asio/ssl/old/detail/openssl_context_service.hpp misc/build/boost_1_55_0/boost/asio/ssl/old/detail/openssl_context_service.hpp
+--- misc/boost_1_55_0/boost/asio/ssl/old/detail/openssl_context_service.hpp	2013-05-20 05:32:20.000000000 -0700
++++ misc/build/boost_1_55_0/boost/asio/ssl/old/detail/openssl_context_service.hpp	2016-03-23 01:11:12.426497000 -0700
+@@ -85,6 +85,13 @@
+       impl = ::SSL_CTX_new(::SSLv2_server_method());
+       break;
+ #endif // defined(OPENSSL_NO_SSL2)
++#if defined(OPENSSL_NO_SSL3)
++    case context_base::sslv3:
++    case context_base::sslv3_client:
++    case context_base::sslv3_server:
++      boost::asio::detail::throw_error(boost::asio::error::invalid_argument);
++      break;
++#else // defined(OPENSSL_NO_SSL3)
+     case context_base::sslv3:
+       impl = ::SSL_CTX_new(::SSLv3_method());
+       break;
+@@ -94,6 +101,7 @@
+     case context_base::sslv3_server:
+       impl = ::SSL_CTX_new(::SSLv3_server_method());
+       break;
++#endif // defined(OPENSSL_NO_SSL3)
+     case context_base::tlsv1:
+       impl = ::SSL_CTX_new(::TLSv1_method());
+       break;
+diff -ur misc/boost_1_55_0/boost/bind/arg.hpp misc/build/boost_1_55_0/boost/bind/arg.hpp
+--- misc/boost_1_55_0/boost/bind/arg.hpp	2007-11-25 10:07:19.000000000 -0800
++++ misc/build/boost_1_55_0/boost/bind/arg.hpp	2016-03-23 01:11:12.421530000 -0700
+@@ -33,8 +33,7 @@
+ 
+     template< class T > arg( T const & /* t */ )
+     {
+-        // static assert I == is_placeholder<T>::value
+-        typedef char T_must_be_placeholder[ I == is_placeholder<T>::value? 1: -1 ];
++        BOOST_STATIC_ASSERT( I == is_placeholder<T>::value );
+     }
+ };
+ 
+diff -ur misc/boost_1_55_0/boost/concept/detail/general.hpp misc/build/boost_1_55_0/boost/concept/detail/general.hpp
+--- misc/boost_1_55_0/boost/concept/detail/general.hpp	2010-06-08 12:31:13.000000000 -0700
++++ misc/build/boost_1_55_0/boost/concept/detail/general.hpp	2016-03-23 01:11:12.388374000 -0700
+@@ -65,10 +65,19 @@
+   
+ # endif
+ 
++// Version check from https://svn.boost.org/trac/boost/changeset/82886
++// (boost/static_assert.hpp)
++#if defined(__GNUC__) && ((__GNUC__ > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 7))) || defined(__clang__)
++#define BOOST_CONCEPT_UNUSED_TYPEDEF __attribute__((unused))
++#else
++#define BOOST_CONCEPT_UNUSED_TYPEDEF /**/
++#endif
++
+ #  define BOOST_CONCEPT_ASSERT_FN( ModelFnPtr )             \
+     typedef ::boost::concepts::detail::instantiate<          \
+     &::boost::concepts::requirement_<ModelFnPtr>::failed>    \
+-      BOOST_PP_CAT(boost_concept_check,__LINE__)
++      BOOST_PP_CAT(boost_concept_check,__LINE__)             \
++      BOOST_CONCEPT_UNUSED_TYPEDEF
+ 
+ }}
+ 
+diff -ur misc/boost_1_55_0/boost/math/special_functions/fpclassify.hpp misc/build/boost_1_55_0/boost/math/special_functions/fpclassify.hpp
+--- misc/boost_1_55_0/boost/math/special_functions/fpclassify.hpp	2013-09-28 09:19:47.000000000 -0700
++++ misc/build/boost_1_55_0/boost/math/special_functions/fpclassify.hpp	2016-03-23 01:11:12.392773000 -0700
+@@ -348,7 +348,7 @@
+ { //!< \brief return true if floating-point type t is finite.
+    typedef detail::fp_traits<long double>::type traits;
+    typedef traits::method method;
+-   typedef boost::is_floating_point<long double>::type fp_tag;
++   //typedef boost::is_floating_point<long double>::type fp_tag;
+    typedef long double value_type;
+    return detail::isfinite_impl(static_cast<value_type>(x), method());
+ }
+@@ -419,7 +419,7 @@
+ {
+    typedef detail::fp_traits<long double>::type traits;
+    typedef traits::method method;
+-   typedef boost::is_floating_point<long double>::type fp_tag;
++   //typedef boost::is_floating_point<long double>::type fp_tag;
+    typedef long double value_type;
+    return detail::isnormal_impl(static_cast<value_type>(x), method());
+ }
+@@ -508,7 +508,7 @@
+ {
+    typedef detail::fp_traits<long double>::type traits;
+    typedef traits::method method;
+-   typedef boost::is_floating_point<long double>::type fp_tag;
++   //typedef boost::is_floating_point<long double>::type fp_tag;
+    typedef long double value_type;
+    return detail::isinf_impl(static_cast<value_type>(x), method());
+ }
+@@ -594,7 +594,7 @@
+ { //!< \brief return true if floating-point type t is NaN (Not A Number).
+    typedef detail::fp_traits<long double>::type traits;
+    typedef traits::method method;
+-   typedef boost::is_floating_point<long double>::type fp_tag;
++   //typedef boost::is_floating_point<long double>::type fp_tag;
+    return detail::isnan_impl(x, method());
+ }
+ #endif
+diff -ur misc/boost_1_55_0/boost/spirit/home/classic/core/primitives/primitives.hpp misc/build/boost_1_55_0/boost/spirit/home/classic/core/primitives/primitives.hpp
+--- misc/boost_1_55_0/boost/spirit/home/classic/core/primitives/primitives.hpp	2008-06-22 08:05:38.000000000 -0700
++++ misc/build/boost_1_55_0/boost/spirit/home/classic/core/primitives/primitives.hpp	2016-03-23 01:11:12.407415000 -0700
+@@ -47,7 +47,6 @@
+         typename parser_result<self_t, ScannerT>::type
+         parse(ScannerT const& scan) const
+         {
+-            typedef typename parser_result<self_t, ScannerT>::type result_t;
+             typedef typename ScannerT::value_t value_t;
+             typedef typename ScannerT::iterator_t iterator_t;
+ 
+diff -ur misc/boost_1_55_0/boost/static_assert.hpp misc/build/boost_1_55_0/boost/static_assert.hpp
+--- misc/boost_1_55_0/boost/static_assert.hpp	2013-09-21 13:17:00.000000000 -0700
++++ misc/build/boost_1_55_0/boost/static_assert.hpp	2016-03-23 01:11:12.430683000 -0700
+@@ -67,7 +67,7 @@
+ //
+ // If the compiler warns about unused typedefs then enable this:
+ //
+-#if defined(__GNUC__) && ((__GNUC__ > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 7)))
++#if defined(__GNUC__) && ((__GNUC__ > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 7))) || defined(__clang__)
+ #  define BOOST_STATIC_ASSERT_UNUSED_ATTRIBUTE __attribute__((unused))
+ #else
+ #  define BOOST_STATIC_ASSERT_UNUSED_ATTRIBUTE
+diff -ur misc/boost_1_55_0/boost/tuple/detail/tuple_basic.hpp misc/build/boost_1_55_0/boost/tuple/detail/tuple_basic.hpp
+--- misc/boost_1_55_0/boost/tuple/detail/tuple_basic.hpp	2011-01-02 12:25:11.000000000 -0800
++++ misc/build/boost_1_55_0/boost/tuple/detail/tuple_basic.hpp	2016-03-23 01:11:12.435344000 -0700
+@@ -225,7 +225,6 @@
+ get(const cons<HT, TT>& c BOOST_APPEND_EXPLICIT_TEMPLATE_NON_TYPE(int, N)) {
+   typedef BOOST_DEDUCED_TYPENAME detail::drop_front<N>::BOOST_NESTED_TEMPLATE
+       apply<cons<HT, TT> > impl;
+-  typedef BOOST_DEDUCED_TYPENAME impl::type cons_element;
+   return impl::call(c).head;
+ }
+ 
+diff -ur misc/boost_1_55_0/boost/unordered/detail/equivalent.hpp misc/build/boost_1_55_0/boost/unordered/detail/equivalent.hpp
+--- misc/boost_1_55_0/boost/unordered/detail/equivalent.hpp	2012-12-05 14:06:57.000000000 -0800
++++ misc/build/boost_1_55_0/boost/unordered/detail/equivalent.hpp	2016-03-23 01:04:46.934774000 -0700
 @@ -534,11 +534,11 @@
              }
  
@@ -86,8 +248,9 @@
              }
  
              return prev;
---- misc/boost_1_55_0/boost/unordered/detail/table.hpp	2013-08-18 11:44:14.000000000 +0200
-+++ misc/build/boost_1_55_0/boost/unordered/detail/table.hpp	2014-01-07 10:18:27.862432325 +0100
+diff -ur misc/boost_1_55_0/boost/unordered/detail/table.hpp misc/build/boost_1_55_0/boost/unordered/detail/table.hpp
+--- misc/boost_1_55_0/boost/unordered/detail/table.hpp	2013-08-18 02:44:14.000000000 -0700
++++ misc/build/boost_1_55_0/boost/unordered/detail/table.hpp	2016-03-23 01:04:46.936005000 -0700
 @@ -257,9 +257,9 @@
              return prev ? iterator(prev->next_) : iterator();
          }
@@ -123,8 +286,9 @@
              }
          }
          
---- misc/boost_1_55_0/boost/unordered/detail/unique.hpp	2013-08-18 11:44:14.000000000 +0200
-+++ misc/build/boost_1_55_0/boost/unordered/detail/unique.hpp	2014-01-07 10:18:27.865432217 +0100
+diff -ur misc/boost_1_55_0/boost/unordered/detail/unique.hpp misc/build/boost_1_55_0/boost/unordered/detail/unique.hpp
+--- misc/boost_1_55_0/boost/unordered/detail/unique.hpp	2013-08-18 02:44:14.000000000 -0700
++++ misc/build/boost_1_55_0/boost/unordered/detail/unique.hpp	2016-03-23 01:04:46.937066000 -0700
 @@ -529,9 +529,9 @@
  
              link_pointer end = static_cast<node_pointer>(prev->next_)->next_;
@@ -162,52 +326,3 @@
          }
  
          ////////////////////////////////////////////////////////////////////////
---- misc/build/boost_1_55_0/boost/bind/arg.hpp	2011-02-02 14:56:49 +0100
-+++ misc/build/boost_1_55_0/boost/bind/arg.hpp	2014-02-10 14:56:49 +0100
-@@ -34,7 +34,8 @@
-     template< class T > arg( T const & /* t */ )
-     {
-         // static assert I == is_placeholder<T>::value
--        typedef char T_must_be_placeholder[ I == is_placeholder<T>::value? 1: -1 ];
-+        char X_must_be_placeholder[ I == is_placeholder<T>::value? 1: -1 ];
-+        (void)&X_must_be_placeholder[0];
-     }
- };
- 
---- misc/boost_1_55_0/boost/tuple/detail/tuple_basic.hpp	2011-01-02 21:25:11 +0100
-+++ misc/build/boost_1_55_0/boost/tuple/detail/tuple_basic.hpp	2014-02-10 14:56:13 +0100
-@@ -225,7 +225,6 @@
- get(const cons<HT, TT>& c BOOST_APPEND_EXPLICIT_TEMPLATE_NON_TYPE(int, N)) {
-   typedef BOOST_DEDUCED_TYPENAME detail::drop_front<N>::BOOST_NESTED_TEMPLATE
-       apply<cons<HT, TT> > impl;
--  typedef BOOST_DEDUCED_TYPENAME impl::type cons_element;
-   return impl::call(c).head;
- }
- 
---- misc/boost_1_55_0/boost/concept/detail/general.hpp	2010-06-08 21:31:13 +0200
-+++ misc/build/boost_1_55_0/boost/concept/detail/general.hpp	2014-03-13 17:20:13 +0100
-@@ -65,10 +65,10 @@
-   
- # endif
- 
--#  define BOOST_CONCEPT_ASSERT_FN( ModelFnPtr )             \
--    typedef ::boost::concepts::detail::instantiate<          \
--    &::boost::concepts::requirement_<ModelFnPtr>::failed>    \
--      BOOST_PP_CAT(boost_concept_check,__LINE__)
-+#define BOOST_CONCEPT_ASSERT_FN( ModelFnPtr )             \
-+    ::boost::concepts::detail::instantiate<               \
-+    &::boost::concepts::requirement_<ModelFnPtr>::failed> \
-+      BOOST_PP_CAT(boost_concept_check,__LINE__)()
- 
- }}
- 
---- misc/boost_1_55_0/boost/spirit/home/classic/core/primitives/primitives.hpp	2014-03-12 14:02:51 +0100
-+++ misc/build/boost_1_55_0/boost/spirit/home/classic/core/primitives/primitives.hpp	2008-06-22 17:05:38 +0200
-@@ -47,7 +47,6 @@
-         typename parser_result<self_t, ScannerT>::type
-         parse(ScannerT const& scan) const
-         {
--            typedef typename parser_result<self_t, ScannerT>::type result_t;
-             typedef typename ScannerT::value_t value_t;
-             typedef typename ScannerT::iterator_t iterator_t;
- 

Modified: openoffice/branches/gbuild-reintegration/main/bootstrap.1
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/bootstrap.1?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/bootstrap.1 (original)
+++ openoffice/branches/gbuild-reintegration/main/bootstrap.1 Mon Aug  1 04:31:52 2016
@@ -54,8 +54,18 @@ chmod +x "$SRC_ROOT/solenv/bin/build_cli
 chmod +x "$SRC_ROOT/solenv/bin/zipdep.pl"
 chmod +x "$SRC_ROOT/solenv/bin/gccinstlib.pl"
 
+# build the AOOJavaDownloader
+mkdir -p "$SOLARENV/$INPATH/class"
+"$JAVACOMPILER" "$SOLARENV/javadownloader/AOOJavaDownloader.java" -d "$SOLARENV/$INPATH/class"
+if [ "$?" != "0" ]; then
+    echo "*** Failed to build AOOJavaDownloader, aborting! ***"
+    exit 1
+fi
+
 # fetch or update external tarballs
 if [ "$DO_FETCH_TARBALLS" = "yes" ]; then
+# check perl include locations
+    "$PERL" -e 'print "\nInclude locations: @INC\n\n"';
     "$PERL" "$SOLARENV/bin/download_external_dependencies.pl" $SRC_ROOT/external_deps.lst
     if [ "$?" != "0" ]; then
         echo "*** Error downloading external dependencies, please fix the previous problems and try again ***"
@@ -68,7 +78,7 @@ fi
 
 if test -n "$DMAKE_URL" -a  ! -x "$SOLARENV/$INPATH/bin/dmake$EXEEXT"; then
 
-    # Assume that the dmake archive has been downloaded by fetch_tarballs.sh
+    # Assume that the dmake archive has been downloaded
     # Determine the name of the downloaded file.
     dmake_package_name=`echo $DMAKE_URL | sed "s/^\(.*\/\)//"`
 

Modified: openoffice/branches/gbuild-reintegration/main/bridges/source/cpp_uno/gcc3_macosx_powerpc/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/bridges/source/cpp_uno/gcc3_macosx_powerpc/uno2cpp.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/bridges/source/cpp_uno/gcc3_macosx_powerpc/uno2cpp.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/bridges/source/cpp_uno/gcc3_macosx_powerpc/uno2cpp.cxx Mon Aug  1 04:31:52 2016
@@ -253,7 +253,7 @@ static void callVirtualMethod(
 		case typelib_TypeClass_HYPER:
 		case typelib_TypeClass_UNSIGNED_HYPER:
 			((long*)pRegisterReturn)[1] = iret2;
-                        // fall thru on purpose
+                        // fall through on purpose
 		case typelib_TypeClass_LONG:
 		case typelib_TypeClass_UNSIGNED_LONG:
 		case typelib_TypeClass_ENUM:

Modified: openoffice/branches/gbuild-reintegration/main/bridges/source/cpp_uno/msvc_win32_intel/except.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/bridges/source/cpp_uno/msvc_win32_intel/except.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/bridges/source/cpp_uno/msvc_win32_intel/except.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/bridges/source/cpp_uno/msvc_win32_intel/except.cxx Mon Aug  1 04:31:52 2016
@@ -584,7 +584,7 @@ int msci_filterCppException(
 #if _MSC_VER < 1400 // msvcr80.dll cleans up, different from former msvcrs
                     // if (! rethrow):
                     // though this unknown exception leaks now, no user-defined
-                    // exception is ever thrown thru the binary C-UNO dispatcher
+                    // exception is ever thrown through the binary C-UNO dispatcher
                     // call stack.
 #endif
 				}
@@ -610,7 +610,7 @@ int msci_filterCppException(
 		}
 	}
     // though this unknown exception leaks now, no user-defined exception
-    // is ever thrown thru the binary C-UNO dispatcher call stack.
+    // is ever thrown through the binary C-UNO dispatcher call stack.
     RuntimeException exc(
         OUString( RTL_CONSTASCII_USTRINGPARAM(
                       "[msci_uno bridge error] unexpected "

Modified: openoffice/branches/gbuild-reintegration/main/bridges/test/com/sun/star/lib/uno/bridges/java_remote/Bug98508_Test.java
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/bridges/test/com/sun/star/lib/uno/bridges/java_remote/Bug98508_Test.java?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/bridges/test/com/sun/star/lib/uno/bridges/java_remote/Bug98508_Test.java (original)
+++ openoffice/branches/gbuild-reintegration/main/bridges/test/com/sun/star/lib/uno/bridges/java_remote/Bug98508_Test.java Mon Aug  1 04:31:52 2016
@@ -33,7 +33,7 @@ import complexlib.ComplexTestCase;
 /**
  * Test case for bug #98508#.
  *
- * <p>Bug #98508# "JAVA UNO bridge is not disposed when Exception occures during
+ * <p>Bug #98508# "JAVA UNO bridge is not disposed when Exception occurs during
  * sendReply()" states that the server returning <code>null</code> instead of a
  * valid <code>String</code> from <code>XServiceName.getServiceName</code>
  * causes an exception when sending the reply, but this exception did not cause

Modified: openoffice/branches/gbuild-reintegration/main/bridges/test/java_uno/nativethreadpool/readme
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/bridges/test/java_uno/nativethreadpool/readme?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/bridges/test/java_uno/nativethreadpool/readme (original)
+++ openoffice/branches/gbuild-reintegration/main/bridges/test/java_uno/nativethreadpool/readme Mon Aug  1 04:31:52 2016
@@ -24,7 +24,7 @@ pool as a C++ URP bridge.  This test cur
 
 There are two processes involved.  The client starts as a native process.  It
 first loads a Java component (Relay) via the in-process JNI bridge, which in
-turn starts to accept incomming URP connections.  The native part of the client
+turn starts to accept incoming URP connections.  The native part of the client
 then connects to the server, retrieves a thread-local token from it, and checks
 the token for correctness.  The server simply waits for a connection from the
 native part of the client, creates a connection to the Java part of the client,

Modified: openoffice/branches/gbuild-reintegration/main/canvas/source/directx/dx_5rm.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/canvas/source/directx/dx_5rm.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/canvas/source/directx/dx_5rm.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/canvas/source/directx/dx_5rm.cxx Mon Aug  1 04:31:52 2016
@@ -523,7 +523,7 @@ namespace dxcanvas
 			virtual ::basegfx::B2IVector getSize();
 
 		private:
-			/// Guard local methods against concurrent acces to RenderModule
+			/// Guard local methods against concurrent access to RenderModule
 			class ImplRenderModuleGuard : private ::boost::noncopyable
 			{
 			public:

Modified: openoffice/branches/gbuild-reintegration/main/canvas/source/directx/dx_9rm.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/canvas/source/directx/dx_9rm.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/canvas/source/directx/dx_9rm.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/canvas/source/directx/dx_9rm.cxx Mon Aug  1 04:31:52 2016
@@ -161,7 +161,7 @@ namespace dxcanvas
 			COMReference<IDirect3DTexture9> getTexture() const;
 
 		private:
-			/// Guard local methods against concurrent acces to RenderModule
+			/// Guard local methods against concurrent access to RenderModule
 			class ImplRenderModuleGuard : private ::boost::noncopyable
 			{
 			public:

Modified: openoffice/branches/gbuild-reintegration/main/canvas/source/directx/dx_vcltools.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/canvas/source/directx/dx_vcltools.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/canvas/source/directx/dx_vcltools.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/canvas/source/directx/dx_vcltools.cxx Mon Aug  1 04:31:52 2016
@@ -181,7 +181,7 @@ namespace dxcanvas
 
                 ENSURE_OR_THROW( pReadAccess.get() != NULL,
                                   "::dxcanvas::tools::bitmapFromVCLBitmapEx(): "
-                                  "Unable to acquire read acces to bitmap" );
+                                  "Unable to acquire read access to bitmap" );
 
                 if( rBmpEx.IsAlpha() )
                 {
@@ -208,7 +208,7 @@ namespace dxcanvas
 
                     ENSURE_OR_THROW( pAlphaReadAccess.get() != NULL,
                                       "::dxcanvas::tools::bitmapFromVCLBitmapEx(): "
-                                      "Unable to acquire read acces to alpha" );
+                                      "Unable to acquire read access to alpha" );
 
                     ENSURE_OR_THROW( pAlphaReadAccess->GetScanlineFormat() == BMP_FORMAT_8BIT_PAL ||
                                       pAlphaReadAccess->GetScanlineFormat() == BMP_FORMAT_8BIT_TC_MASK,
@@ -351,7 +351,7 @@ namespace dxcanvas
 
                     ENSURE_OR_THROW( pMaskReadAccess.get() != NULL,
                                       "::dxcanvas::tools::bitmapFromVCLBitmapEx(): "
-                                      "Unable to acquire read acces to mask" );
+                                      "Unable to acquire read access to mask" );
 
                     ENSURE_OR_THROW( pMaskReadAccess->GetScanlineFormat() == BMP_FORMAT_1BIT_MSB_PAL,
                                       "::dxcanvas::tools::bitmapFromVCLBitmapEx(): "

Modified: openoffice/branches/gbuild-reintegration/main/chart2/source/controller/dialogs/res_LegendPosition.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/chart2/source/controller/dialogs/res_LegendPosition.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/chart2/source/controller/dialogs/res_LegendPosition.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/chart2/source/controller/dialogs/res_LegendPosition.cxx Mon Aug  1 04:31:52 2016
@@ -245,7 +245,7 @@ void LegendPositionResources::writeToIte
 
 IMPL_LINK( LegendPositionResources, PositionChangeHdl, RadioButton*, pRadio )
 {
-    //for each radio click ther are coming two change events
+    //for each radio click there are coming two change events
     //first uncheck of previous button -> ignore that call
     //the second call gives the check of the new button
     if( pRadio && pRadio->IsChecked() )

Modified: openoffice/branches/gbuild-reintegration/main/chart2/source/controller/dialogs/tp_ChartType.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/chart2/source/controller/dialogs/tp_ChartType.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/chart2/source/controller/dialogs/tp_ChartType.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/chart2/source/controller/dialogs/tp_ChartType.cxx Mon Aug  1 04:31:52 2016
@@ -430,7 +430,7 @@ void StackingResourceGroup::fillParamete
 }
 IMPL_LINK( StackingResourceGroup, StackingChangeHdl, RadioButton*, pRadio )
 {
-    //for each radio click ther are coming two change events
+    //for each radio click there are coming two change events
     //first uncheck of previous button -> ignore that call
     //the second call gives the check of the new button
     if( m_pChangeListener && pRadio && pRadio->IsChecked() )

Modified: openoffice/branches/gbuild-reintegration/main/chart2/source/controller/dialogs/tp_Scale.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/chart2/source/controller/dialogs/tp_Scale.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/chart2/source/controller/dialogs/tp_Scale.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/chart2/source/controller/dialogs/tp_Scale.cxx Mon Aug  1 04:31:52 2016
@@ -595,7 +595,7 @@ int ScaleTabPage::DeactivatePage(SfxItem
     if( chart2::AxisType::REALNUMBER != m_nAxisType )
         aCbxLogarithm.Show( false );
 
-    //check wich entries need user action
+    //check which entries need user action
 
     if ( aCbxLogarithm.IsChecked() &&
             ( ( !aCbxAutoMin.IsChecked() && fMin <= 0.0 )

Modified: openoffice/branches/gbuild-reintegration/main/chart2/source/tools/ObjectIdentifier.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/chart2/source/tools/ObjectIdentifier.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/chart2/source/tools/ObjectIdentifier.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/chart2/source/tools/ObjectIdentifier.cxx Mon Aug  1 04:31:52 2016
@@ -559,7 +559,7 @@ OUString ObjectIdentifier::createParticl
     OUStringBuffer aRet;
     
     Reference< XDiagram > xDiagram( ChartModelHelper::findDiagram( xChartModel ) );
-    //todo: if more than one diagram is implemeted, find the correct diagram wich is owner of the given legend
+    //todo: if more than one diagram is implemeted, find the correct diagram which is owner of the given legend
 
     aRet.append( ObjectIdentifier::createParticleForDiagram( xDiagram, xChartModel ) );
     aRet.appendAscii(":");

Modified: openoffice/branches/gbuild-reintegration/main/chart2/source/view/axes/VCartesianAxis.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/chart2/source/view/axes/VCartesianAxis.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/chart2/source/view/axes/VCartesianAxis.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/chart2/source/view/axes/VCartesianAxis.cxx Mon Aug  1 04:31:52 2016
@@ -1439,7 +1439,7 @@ void VCartesianAxis::createMaximumLabels
         pTickFactory2D->updateScreenValues( m_aAllTickInfos );
 
         //create tick mark text shapes
-        //@todo: iterate through all tick depth wich should be labeled
+        //@todo: iterate through all tick depth which should be labeled
 
         AxisLabelProperties aAxisLabelProperties( m_aAxisLabelProperties );
         if( isAutoStaggeringOfLabelsAllowed( aAxisLabelProperties, pTickFactory2D->isHorizontalAxis(), pTickFactory2D->isVerticalAxis() ) )

Modified: openoffice/branches/gbuild-reintegration/main/chart2/source/view/axes/VPolarAngleAxis.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/chart2/source/view/axes/VPolarAngleAxis.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/chart2/source/view/axes/VPolarAngleAxis.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/chart2/source/view/axes/VPolarAngleAxis.cxx Mon Aug  1 04:31:52 2016
@@ -183,7 +183,7 @@ void VPolarAngleAxis::createLabels()
         std::auto_ptr< TickFactory > apTickFactory( this->createTickFactory() );
 
         //create tick mark text shapes
-        //@todo: iterate through all tick depth wich should be labeled
+        //@todo: iterate through all tick depth which should be labeled
 
         EquidistantTickIter aTickIter( m_aAllTickInfos, m_aIncrement, 0, 0 );
         this->updateUnscaledValuesAtTicks( aTickIter );

Modified: openoffice/branches/gbuild-reintegration/main/chart2/source/view/inc/PlottingPositionHelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/chart2/source/view/inc/PlottingPositionHelper.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/chart2/source/view/inc/PlottingPositionHelper.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/chart2/source/view/inc/PlottingPositionHelper.hxx Mon Aug  1 04:31:52 2016
@@ -149,7 +149,7 @@ protected: //member
     bool   m_bAllowShiftZAxisPos;
 };
 
-//describes wich axis of the drawinglayer scene or sreen axis are the normal axis
+//describes which axis of the drawinglayer scene or sreen axis are the normal axis
 enum NormalAxis
 {
       NormalAxis_X

Modified: openoffice/branches/gbuild-reintegration/main/chart2/source/view/main/PropertyMapper.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/chart2/source/view/main/PropertyMapper.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/chart2/source/view/main/PropertyMapper.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/chart2/source/view/main/PropertyMapper.cxx Mon Aug  1 04:31:52 2016
@@ -198,7 +198,7 @@ const tMakePropertyNameMap& PropertyMapp
         ( C2U( "CharColor" ),               C2U("CharColor") )
         ( C2U( "CharContoured" ),           C2U("CharContoured") )
 /////// ( C2U( "CharCrossedOut" ),          C2U("CharCrossedOut") ) //setting this explicitly somehow conflicts with CharStrikeout
-        ( C2U( "CharEmphasis" ),            C2U("CharEmphasis") )//the service style::CharacterProperties  describes a property called 'CharEmphasize' wich is nowhere implemented
+        ( C2U( "CharEmphasis" ),            C2U("CharEmphasis") )//the service style::CharacterProperties  describes a property called 'CharEmphasize' which is nowhere implemented
 //        ( C2U( "CharEscapement" ),          C2U("CharEscapement") ) //#i98344# @future: add these to properties again, if the user interface offers the possibility to change them; then make sure that older wrong files are corrected on import
 //        ( C2U( "CharEscapementHeight" ),    C2U("CharEscapementHeight") ) //#i98344# @future: add these to properties again, if the user interface offers the possibility to change them; then make sure that older wrong files are corrected on import
 //      ( C2U( "CharFlash" ),               C2U("Flashing") )

Modified: openoffice/branches/gbuild-reintegration/main/cli_ure/source/ure/uno/util/WeakComponentBase.cs
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/cli_ure/source/ure/uno/util/WeakComponentBase.cs?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/cli_ure/source/ure/uno/util/WeakComponentBase.cs (original)
+++ openoffice/branches/gbuild-reintegration/main/cli_ure/source/ure/uno/util/WeakComponentBase.cs Mon Aug  1 04:31:52 2016
@@ -117,7 +117,7 @@ public class WeakComponentBase : WeakBas
                 doDispose = true;
             }
         }
-        // The notification occures in an unsynchronized block in order to avoid
+        // The notification occurs in an unsynchronized block in order to avoid
         // deadlocks if one of the listeners calls back in a different thread on
         // a synchronized method which uses the same object.
         if (doDispose)

Modified: openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/accessiblecontexthelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/accessiblecontexthelper.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/accessiblecontexthelper.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/accessiblecontexthelper.hxx Mon Aug  1 04:31:52 2016
@@ -246,7 +246,7 @@ namespace comphelper
 		// life time control
 		/// checks whether the object is alive (returns <TRUE/> then) or disposed
 		sal_Bool	isAlive() const;
-		/// checks for beeing alive. If the object is already disposed (i.e. not alive), an exception is thrown.
+		/// checks for being alive. If the object is already disposed (i.e. not alive), an exception is thrown.
 		void		ensureAlive() const SAL_THROW( ( ::com::sun::star::lang::DisposedException ) );
 
 		/** ensures that the object is disposed.

Modified: openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/implbase_var.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/implbase_var.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/implbase_var.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/implbase_var.hxx Mon Aug  1 04:31:52 2016
@@ -182,7 +182,7 @@ public:
     ::com::sun::star::lang::XTypeProvider and
     ::com::sun::star::uno::XInterface
     which supports weak mechanism to be held weakly
-    (supporting ::com::sun::star::uno::XWeak thru ::cppu::OWeakObject).
+    (supporting ::com::sun::star::uno::XWeak through ::cppu::OWeakObject).
     
     @derive
     Inherit from this class giving your interface(s) to be implemented as

Modified: openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/locale.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/locale.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/numberedcollection.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/numberedcollection.hxx Mon Aug  1 04:31:52 2016
@@ -159,7 +159,7 @@ class COMPHELPER_DLLPUBLIC NumberedColle
                     is no free number) the special value INVALID_NUMBER will be returned.
     
             @note   Those method can't be called within a multithreaded environment ..
-                    Because such number wont be "reserved" for the calli of these method
+                    Because such number won't be "reserved" for the calli of these method
                     it can happen that two calls returns the same number (reasoned by the fact that first calli
                     doesn't used the returned number already.
     

Modified: openoffice/branches/gbuild-reintegration/main/comphelper/source/misc/uieventslogger.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/comphelper/source/misc/uieventslogger.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/comphelper/source/misc/uieventslogger.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/comphelper/source/misc/uieventslogger.cxx Mon Aug  1 04:31:52 2016
@@ -308,7 +308,7 @@ namespace comphelper
 
     void UiEventsLogger::disposing()
     {
-        // we dont want to create an instance just to dispose it
+        // we don't want to create an instance just to dispose it
         UiEventsLogger_Impl::prepareMutex();
         Guard<Mutex> singleton_guard(UiEventsLogger_Impl::singleton_mutex);
         if(UiEventsLogger_Impl::instance!=UiEventsLogger_Impl::ptr())

Modified: openoffice/branches/gbuild-reintegration/main/comphelper/source/property/propertystatecontainer.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/comphelper/source/property/propertystatecontainer.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/comphelper/source/property/propertystatecontainer.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/comphelper/source/property/propertystatecontainer.cxx Mon Aug  1 04:31:52 2016
@@ -100,7 +100,7 @@ namespace comphelper
 			return aStates;
 
 #ifdef _DEBUG
-		// precondition: property sequence is sorted (the algorythm below relies on this)
+		// precondition: property sequence is sorted (the algorithm below relies on this)
 		{
 			const ::rtl::OUString* pNames = _rPropertyNames.getConstArray();
 			const ::rtl::OUString* pNamesCompare = pNames + 1;

Modified: openoffice/branches/gbuild-reintegration/main/configure.ac
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/configure.ac?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/configure.ac (original)
+++ openoffice/branches/gbuild-reintegration/main/configure.ac Mon Aug  1 04:31:52 2016
@@ -2008,7 +2008,7 @@ dnl The list of required Perl modules is
 dnl     http://wiki.openoffice.org/wiki/Documentation/Building_Guide_AOO#General_Build_Requirements
 dnl ===================================================================
 AC_MSG_CHECKING([for required Perl modules])
-if `$PERL -e 'use Archive::Zip; use LWP::UserAgent; use XML::Parser;'>/dev/null 2>&1`; then
+if `$PERL -e 'use Archive::Zip; use LWP::UserAgent; use XML::Parser; use LWP::Protocol'>/dev/null 2>&1`; then
 	AC_MSG_RESULT([all modules found])
 else
     # Find out which modules are missing.
@@ -2019,6 +2019,10 @@ else
     if ! `$PERL -e 'use LWP::UserAgent;'>/dev/null 2>&1`; then
        missing_perl_modules="$missing_perl_modules LWP::UserAgent"
     fi
+    if ! `$PERL -e 'use LWP::Protocol;'>/dev/null 2>&1`; then
+       missing_perl_modules="$missing_perl_modules LWP::Protocol"
+    fi
+
     if ! `$PERL -e 'use XML::Parser;'>/dev/null 2>&1`; then
        missing_perl_modules="$missing_perl_modules XML::Parser"
     fi

Modified: openoffice/branches/gbuild-reintegration/main/connectivity/inc/connectivity/sqlparse.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/connectivity/inc/connectivity/sqlparse.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/connectivity/inc/connectivity/sqlparse.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/connectivity/inc/connectivity/sqlparse.hxx Mon Aug  1 04:31:52 2016
@@ -37,8 +37,10 @@
 #include <com/sun/star/i18n/XCharacterClassification.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/i18n/XLocaleData.hpp>
+#include <com/sun/star/lang/Locale.hpp>
 #include "connectivity/IParseContext.hxx"
 #include "connectivity/dbtoolsdllapi.hxx"
+#include "connectivity/sqlerror.hxx"
 #include <salhelper/singletonref.hxx>
 #include <osl/mutex.hxx>
 
@@ -130,7 +132,14 @@ namespace connectivity
 	//==========================================================================
 	//= OSQLParser
 	//==========================================================================
-    struct OSQLParser_Data;
+    struct OSQLParser_Data
+    {
+        ::com::sun::star::lang::Locale  aLocale;
+        ::connectivity::SQLError        aErrors;
+
+        OSQLParser_Data( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory >& _xServiceFactory );
+
+    };		
 	/** Parser for SQL92
 	*/
 	class OOO_DLLPUBLIC_DBTOOLS OSQLParser

Modified: openoffice/branches/gbuild-reintegration/main/connectivity/inc/connectivity/virtualdbtools.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/connectivity/inc/connectivity/virtualdbtools.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/connectivity/inc/connectivity/virtualdbtools.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/connectivity/inc/connectivity/virtualdbtools.hxx Mon Aug  1 04:31:52 2016
@@ -272,7 +272,7 @@ namespace connectivity
 		//================================================================
 		//= ISQLParseNode
 		//================================================================
-		/** a simple version of the OSQLParseNode, with all methods beeing virtual
+		/** a simple version of the OSQLParseNode, with all methods being virtual
 		*/
 		class OOO_DLLPUBLIC_DBTOOLS ISQLParseNode : public ::rtl::IReference
 		{
@@ -295,7 +295,7 @@ namespace connectivity
 		//================================================================
 		//= ISQLParser
 		//================================================================
-		/** a simple version of the OSQLParser, with all methods beeing virtual
+		/** a simple version of the OSQLParser, with all methods being virtual
 		*/
 		class OOO_DLLPUBLIC_DBTOOLS ISQLParser : public ::rtl::IReference
 		{

Modified: openoffice/branches/gbuild-reintegration/main/connectivity/source/drivers/flat/ETable.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/connectivity/source/drivers/flat/ETable.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/connectivity/source/drivers/flat/ETable.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/connectivity/source/drivers/flat/ETable.cxx Mon Aug  1 04:31:52 2016
@@ -72,26 +72,26 @@ void OFlatTable::fillColumns(const ::com
 
 	QuotedTokenizedString aHeaderLine;
 	OFlatConnection* pConnection = (OFlatConnection*)m_pConnection;
-    const rtl_TextEncoding nEncoding = m_pConnection->getTextEncoding();
     const sal_Bool bHasHeaderLine = pConnection->isHeaderLine();
+    sal_Int32 nCurPos;
 	if ( bHasHeaderLine )
 	{
 		while(bRead && !aHeaderLine.Len())
 		{
-			bRead = m_pFileStream->ReadByteStringLine(aHeaderLine,nEncoding);
+			bRead = readLine(aHeaderLine, nCurPos);
 		}
         m_nStartRowFilePos = m_pFileStream->Tell();
 	}
 
 	// read first row
 	QuotedTokenizedString aFirstLine;
-	bRead = m_pFileStream->ReadByteStringLine(aFirstLine,nEncoding);
+	bRead = readLine(aFirstLine, nCurPos);
 
 	if ( !bHasHeaderLine || !aHeaderLine.Len())
 	{
 		while(bRead && !aFirstLine.Len())
 		{
-			bRead = m_pFileStream->ReadByteStringLine(aFirstLine,nEncoding);
+			bRead = readLine(aFirstLine, nCurPos);
 		}
 		// use first row as headerline because we need the number of columns
 		aHeaderLine = aFirstLine;
@@ -155,7 +155,7 @@ void OFlatTable::fillColumns(const ::com
 	    }
         ++nRowCount;
     }
-    while(nRowCount < nMaxRowsToScan && m_pFileStream->ReadByteStringLine(aFirstLine,nEncoding) && !m_pFileStream->IsEof());
+    while(nRowCount < nMaxRowsToScan && readLine(aFirstLine,nCurPos) && !m_pFileStream->IsEof());
 
     for (xub_StrLen i = 0; i < nFieldCount; i++)
     {
@@ -895,21 +895,76 @@ sal_Bool OFlatTable::seekRow(IResultSetH
 // -----------------------------------------------------------------------------
 sal_Bool OFlatTable::readLine(sal_Int32& _rnCurrentPos)
 {
+    return readLine(m_aCurrentLine, _rnCurrentPos);
+}
+// -----------------------------------------------------------------------------
+sal_Bool OFlatTable::readLine(QuotedTokenizedString& line, sal_Int32& _rnCurrentPos)
+{
     RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "flat", "Ocke.Janssen@sun.com", "OFlatTable::readLine" );
     const rtl_TextEncoding nEncoding = m_pConnection->getTextEncoding();
-    m_pFileStream->ReadByteStringLine(m_aCurrentLine,nEncoding);
-	if (m_pFileStream->IsEof())
-		return sal_False;
-
-    QuotedTokenizedString sLine = m_aCurrentLine; // check if the string continues on next line
-    while( (sLine.GetString().GetTokenCount(m_cStringDelimiter) % 2) != 1 )
+    m_pFileStream->ReadByteStringLine(line,nEncoding);
+    if (m_pFileStream->IsEof())
+        return sal_False;
+
+    QuotedTokenizedString sLine = line; // check if the string continues on next line
+    xub_StrLen nLastOffset = 0;
+    bool isQuoted = false;
+    bool isFieldStarting = true;
+    while (sLine.Len() < STRING_MAXLEN)
     {
-        m_pFileStream->ReadByteStringLine(sLine,nEncoding);
-        if ( !m_pFileStream->IsEof() )
+        bool wasQuote = false;
+        const sal_Unicode *p;
+        p = sLine.GetString().GetBuffer();
+        p += nLastOffset;
+
+        while (*p)
         {
-            m_aCurrentLine.GetString().Append('\n');
-            m_aCurrentLine.GetString() += sLine.GetString();
-            sLine = m_aCurrentLine;
+            if (isQuoted)
+            {
+                if (*p == m_cStringDelimiter)
+                    wasQuote = !wasQuote;
+                else
+                {
+                    if (wasQuote)
+                    {
+                        wasQuote = false;
+                        isQuoted = false;
+                        if (*p == m_cFieldDelimiter)
+                            isFieldStarting = true;
+                    }
+                }
+            }
+            else
+            {
+                if (isFieldStarting)
+                {
+                    isFieldStarting = false;
+                    if (*p == m_cStringDelimiter)
+                        isQuoted = true;
+                    else if (*p == m_cFieldDelimiter)
+                        isFieldStarting = true;
+                }
+                else if (*p == m_cFieldDelimiter)
+                    isFieldStarting = true;
+            }
+            ++p;
+        }
+
+        if (wasQuote)
+            isQuoted = false;
+
+        if (isQuoted)
+        {
+            nLastOffset = sLine.Len();
+            m_pFileStream->ReadByteStringLine(sLine,nEncoding);
+            if ( !m_pFileStream->IsEof() )
+            {
+                line.GetString().Append('\n');
+                line.GetString() += sLine.GetString();
+                sLine = line;
+            }
+            else
+                break;
         }
         else
             break;
@@ -917,4 +972,3 @@ sal_Bool OFlatTable::readLine(sal_Int32&
     _rnCurrentPos = m_pFileStream->Tell();
     return sal_True;
 }
-

Modified: openoffice/branches/gbuild-reintegration/main/connectivity/source/inc/flat/ETable.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/connectivity/source/inc/flat/ETable.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/connectivity/source/inc/flat/ETable.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/connectivity/source/inc/flat/ETable.hxx Mon Aug  1 04:31:52 2016
@@ -64,6 +64,7 @@ namespace connectivity
 			void fillColumns(const ::com::sun::star::lang::Locale& _aLocale);
 			sal_Bool CreateFile(const INetURLObject& aFile, sal_Bool& bCreateMemo);
             sal_Bool readLine(sal_Int32& _rnCurrentPos);
+            sal_Bool readLine(QuotedTokenizedString& line, sal_Int32& _rnCurrentPos);
             void impl_fillColumnInfo_nothrow(QuotedTokenizedString& aFirstLine,xub_StrLen& nStartPosFirstLine,xub_StrLen& nStartPosFirstLine2
                                              ,sal_Int32& io_nType,sal_Int32& io_nPrecisions,sal_Int32& io_nScales,String& o_sTypeName
                                              ,const sal_Unicode cDecimalDelimiter,const sal_Unicode cThousandDelimiter,const CharClass& aCharClass);

Modified: openoffice/branches/gbuild-reintegration/main/connectivity/source/inc/hsqldb/HConnection.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/connectivity/source/inc/hsqldb/HConnection.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/connectivity/source/inc/hsqldb/HConnection.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/connectivity/source/inc/hsqldb/HConnection.hxx Mon Aug  1 04:31:52 2016
@@ -117,7 +117,7 @@ namespace connectivity
                     if creating the dialog instance fails
 
                 @throws ::com::sun::star::uno::RuntimeException
-                    if a serious error occures
+                    if a serious error occurs
 
                 @precond
                     Our mutex is locked.

Modified: openoffice/branches/gbuild-reintegration/main/connectivity/source/inc/odbc/ODatabaseMetaDataResultSet.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/connectivity/source/inc/odbc/ODatabaseMetaDataResultSet.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/connectivity/source/inc/odbc/ODatabaseMetaDataResultSet.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/connectivity/source/inc/odbc/ODatabaseMetaDataResultSet.hxx Mon Aug  1 04:31:52 2016
@@ -80,7 +80,7 @@ namespace connectivity
 			rtl_TextEncoding							m_nTextEncoding;
 			sal_Int32									m_nRowPos;
 			sal_Int32									m_nLastColumnPos;		// used for m_aRow just to know where we are
-			sal_Int32									m_nDriverColumnCount;	// column count of the driver wich can sometimes be less than the metadata count
+			sal_Int32									m_nDriverColumnCount;	// column count of the driver which can sometimes be less than the metadata count
 			SQLRETURN									m_nCurrentFetchState;
 			sal_Bool									m_bWasNull;
 			sal_Bool									m_bEOF;					// after last record

Modified: openoffice/branches/gbuild-reintegration/main/connectivity/source/parse/sqlnode.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/connectivity/source/parse/sqlnode.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/connectivity/source/parse/sqlnode.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/connectivity/source/parse/sqlnode.cxx Mon Aug  1 04:31:52 2016
@@ -148,16 +148,13 @@ namespace connectivity
 {
 
 //=============================================================================
-struct OSQLParser_Data
+//= OSQLParser_Data
+//=============================================================================
+//-----------------------------------------------------------------------------
+OSQLParser_Data::OSQLParser_Data( const Reference< XMultiServiceFactory >& _xServiceFactory )
+    :aErrors( _xServiceFactory )
 {
-    ::com::sun::star::lang::Locale  aLocale;
-    ::connectivity::SQLError        aErrors;
-
-    OSQLParser_Data( const Reference< XMultiServiceFactory >& _xServiceFactory )
-        :aErrors( _xServiceFactory )
-    {
-    }
-};
+}
 
 //=============================================================================
 //= SQLParseNodeParameter

Modified: openoffice/branches/gbuild-reintegration/main/curl/makefile.mk
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/curl/makefile.mk?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/curl/makefile.mk (original)
+++ openoffice/branches/gbuild-reintegration/main/curl/makefile.mk Mon Aug  1 04:31:52 2016
@@ -37,15 +37,15 @@ all:
 
 # --- Files --------------------------------------------------------
 
-TARFILE_NAME=curl-7.19.7
-TARFILE_MD5=ecb2e37e45c9933e2a963cabe03670ab
-PATCH_FILES=curl-7.19.7.patch
+TARFILE_NAME=curl-7.49.1
+TARFILE_MD5=2feb3767b958add6a177c6602ff21e8c
+PATCH_FILES=
 
 .IF "$(GUI)"=="WNT"
-	PATCH_FILES+=curl-7.19.7_win.patch
-	.IF "$(COM)"=="GCC"
-		PATCH_FILES+=curl-7.19.7_mingw.patch
-	.ENDIF
+	PATCH_FILES+=curl-7.49.1_win.patch
+#	.IF "$(COM)"=="GCC"
+#		PATCH_FILES+=curl-7.19.7_mingw.patch
+#	.ENDIF
 .ENDIF
 
 
@@ -141,7 +141,7 @@ OUT2INC= \
 	include$/curl$/multi.h  		\
 	include$/curl$/curl.h  			\
 	include$/curl$/curlver.h  		\
-	include$/curl$/types.h  		\
+	include$/curl$/typecheck-gcc.h  	\
 	include$/curl$/stdcheaders.h  	\
 	include$/curl$/mprintf.h	    \
 	include$/curl$/curlbuild.h		\

Modified: openoffice/branches/gbuild-reintegration/main/curl/prj/d.lst
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/curl/prj/d.lst?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/curl/prj/d.lst (original)
+++ openoffice/branches/gbuild-reintegration/main/curl/prj/d.lst Mon Aug  1 04:31:52 2016
@@ -5,11 +5,11 @@ mkdir: %_DEST%\inc%_EXT%\external\curl
 ..\%__SRC%\inc\mprintf.h %_DEST%\inc%_EXT%\external\curl\mprintf.h
 ..\%__SRC%\inc\multi.h %_DEST%\inc%_EXT%\external\curl\multi.h
 ..\%__SRC%\inc\stdcheaders.h %_DEST%\inc%_EXT%\external\curl\stdcheaders.h
-..\%__SRC%\inc\types.h %_DEST%\inc%_EXT%\external\curl\types.h
+..\%__SRC%\inc\typecheck-gcc.h %_DEST%\inc%_EXT%\external\curl\typecheck-gcc.h
 ..\%__SRC%\inc\curlbuild.h %_DEST%\inc%_EXT%\external\curl\curlbuild.h
 ..\%__SRC%\inc\curlrules.h %_DEST%\inc%_EXT%\external\curl\curlrules.h
 
 ..\%__SRC%\bin\libcurl*.dll %_DEST%\bin%_EXT%\*.dll
 ..\%__SRC%\lib\libcurl.* %_DEST%\lib%_EXT%\libcurl.*
 
-linklib: libcurl.*.*
\ No newline at end of file
+linklib: libcurl.*.*

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/inc/dbsubcomponentcontroller.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/inc/dbsubcomponentcontroller.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/inc/dbsubcomponentcontroller.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/inc/dbsubcomponentcontroller.hxx Mon Aug  1 04:31:52 2016
@@ -176,7 +176,7 @@ namespace dbaui
 		virtual void        reconnect( sal_Bool _bUI );
                 sal_Bool    ensureConnected( sal_Bool _bUI )	{ if ( !isConnected() ) reconnect( _bUI ); return isConnected(); }
 
-		/** called when our connection is beeing disposed
+		/** called when our connection is being disposed
 			<p>The default implementation does a reconnect</p>
 		*/
 		virtual void losingConnection( );

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/api/querycontainer.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/api/querycontainer.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/api/querycontainer.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/api/querycontainer.cxx Mon Aug  1 04:31:52 2016
@@ -363,7 +363,7 @@ Reference< XVeto > SAL_CALL OQueryContai
 void SAL_CALL OQueryContainer::disposing( const ::com::sun::star::lang::EventObject& _rSource ) throw(::com::sun::star::uno::RuntimeException)
 {
 	if (_rSource.Source.get() == Reference< XInterface >(m_xCommandDefinitions, UNO_QUERY).get())
-	{	// our "master container" (with the command definitions) is beeing disposed
+	{	// our "master container" (with the command definitions) is being disposed
 		DBG_ERROR("OQueryContainer::disposing : nobody should dispose the CommandDefinition container before disposing my connection !");
 		dispose();
 	}

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/dataaccess/ModelImpl.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/dataaccess/ModelImpl.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/dataaccess/ModelImpl.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/dataaccess/ModelImpl.hxx Mon Aug  1 04:31:52 2016
@@ -274,7 +274,7 @@ public:
             - this is an automatism for data safety reasons.
             If you pass <TRUE/> here, committing the root storage is prevented for this particular
             call.
-		@return <TRUE/> if the storage could be commited, otherwise <FALSE/>
+		@return <TRUE/> if the storage could be committed, otherwise <FALSE/>
 	*/
 	bool        commitEmbeddedStorage( bool _bPreventRootCommits = false );
 

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/dataaccess/bookmarkcontainer.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/dataaccess/bookmarkcontainer.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/dataaccess/bookmarkcontainer.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/dataaccess/bookmarkcontainer.hxx Mon Aug  1 04:31:52 2016
@@ -170,7 +170,7 @@ protected:
 	*/
 	void		checkValid(sal_Bool _bIntendWriteAccess) const throw (::com::sun::star::uno::RuntimeException, ::com::sun::star::lang::DisposedException);
 
-	/** quickly checks if there already is an element with a given name. No access to the configuration occures, i.e.
+	/** quickly checks if there already is an element with a given name. No access to the configuration occurs, i.e.
 		if there is such an object which is not already loaded, it won't be loaded now.
 		@param		_rName		the object name to check
 		@return					sal_True if there already exists such an object

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/inc/definitioncontainer.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/inc/definitioncontainer.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/recovery/dbdocrecovery.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/recovery/dbdocrecovery.cxx Mon Aug  1 04:31:52 2016
@@ -378,7 +378,7 @@ namespace dbaccess
             Reference< XStorage > xComponentsStor( xRecoveryStorage->openStorageElement(
                 SubComponentRecovery::getComponentsStorageName( eComponentType ), ElementModes::READ ), UNO_QUERY_THROW );
 
-            // loop thru all components of this type
+            // loop through all components of this type
             for (   MapStringToCompDesc::const_iterator stor = map->second.begin();
                     stor != map->second.end();
                     ++stor

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/ext/macromigration/migrationengine.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/ext/macromigration/migrationengine.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/ext/macromigration/migrationengine.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/ext/macromigration/migrationengine.cxx Mon Aug  1 04:31:52 2016
@@ -1552,7 +1552,7 @@ namespace dbmm
                     if ( !xSourceLibraries->isLibraryLoaded( *pSourceLibName ) )
                         xSourceLibraries->loadLibrary( *pSourceLibName );
 
-                    // copy the content of this particular libary
+                    // copy the content of this particular library
                     Reference< XNameAccess > xSourceLib( xSourceLibraries->getByName( *pSourceLibName ), UNO_QUERY_THROW );
                     Reference< XNameContainer > xTargetLib( xTargetLibraries->createLibrary( sNewLibName ), UNO_QUERY_THROW );
 

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/browser/sbagrid.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/browser/sbagrid.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/browser/sbagrid.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/browser/sbagrid.cxx Mon Aug  1 04:31:52 2016
@@ -816,7 +816,7 @@ sal_Bool SbaGridHeader::ImplStartColumnD
 		EndTracking(ENDTRACK_CANCEL | ENDTRACK_END);
 
 		// because we have 3d-buttons the select handler is called from MouseButtonUp, but StartDrag
-		// occures earlier (while the mouse button is down)
+		// occurs earlier (while the mouse button is down)
 		// so for optical reasons we select the column before really starting the drag operation.
 		notifyColumnSelect(nId);
 

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/browser/unodatbr.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/browser/unodatbr.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/browser/unodatbr.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/browser/unodatbr.cxx Mon Aug  1 04:31:52 2016
@@ -3453,7 +3453,7 @@ IMPL_LINK( SbaTableQueryBrowser, OnTreeE
 	if (isContainer(pRHS))
 	{
 		// don't use getEntryType (directly or indirecly) for the LHS:
-		// LHS is currently beeing inserted, so it is not "completely valid" at the moment
+		// LHS is currently being inserted, so it is not "completely valid" at the moment
 
 		const EntryType eRight = getEntryType(pRHS);
 		if (etTableContainer == eRight)
@@ -3871,7 +3871,7 @@ void SbaTableQueryBrowser::impl_cleanupD
         return;
 
     if ( isSelected( pDataSourceEntry ) )
-	{	// a table or query belonging to the deleted data source is currently beeing displayed.
+	{	// a table or query belonging to the deleted data source is currently being displayed.
 		OSL_ENSURE( m_pTreeView->getListBox().GetRootLevelParent( m_pCurrentlyDisplayed ) == pDataSourceEntry,
             "SbaTableQueryBrowser::impl_cleanupDataSourceEntry: inconsistence (1)!" );
 		unloadAndCleanup( sal_True );

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/dlg/DbAdminImpl.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/dlg/DbAdminImpl.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/dlg/DbAdminImpl.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/dlg/DbAdminImpl.cxx Mon Aug  1 04:31:52 2016
@@ -414,7 +414,7 @@ Reference< XDriver > ODbDataSourceAdmini
 	// get the global DriverManager
 	Reference< XDriverAccess > xDriverManager;
 	String sCurrentActionError = String(ModuleRes(STR_COULDNOTCREATE_DRIVERMANAGER));
-		// in case an error occures
+		// in case an error occurs
 	sCurrentActionError.SearchAndReplaceAscii("#servicename#", (::rtl::OUString)SERVICE_SDBC_CONNECTIONPOOL);
 	try
 	{

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/dlg/dbfindex.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/dlg/dbfindex.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/dlg/dbfindex.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/dlg/dbfindex.cxx Mon Aug  1 04:31:52 2016
@@ -425,7 +425,7 @@ void ODbaseIndexDialog::Init()
 					// and remove it from the free index list
 					aUsedIndexes.push_back(aEntry);
 						// do this later below. We may not have encountered the index file, yet, thus we may not
-						// know the index as beeing free, yet
+						// know the index as being free, yet
 				}
 
 			}

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/JoinTableView.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/JoinTableView.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/JoinTableView.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/JoinTableView.hxx Mon Aug  1 04:31:52 2016
@@ -205,7 +205,7 @@ namespace dbaui
 		/** getConnectionCount returns how many connection belongs to single table
 			@param	_pFromWin	the table for which connections should be found
 
-			@return	the count of connections wich belongs to this table
+			@return	the count of connections which belongs to this table
 		*/
 		sal_Int32 getConnectionCount(const OTableWindow* _pFromWin) const;
 

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/RelationDlg.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/RelationDlg.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/RelationDlg.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/RelationDlg.hxx Mon Aug  1 04:31:52 2016
@@ -95,7 +95,7 @@ namespace dbaui
 
 		virtual short Execute();
 
-		/** getTableMap gives acces to the table window map
+		/** getTableMap gives access to the table window map
 			@retrun the table window from the join view
 		*/
 		OJoinTableView::OTableWindowMap* getTableMap() const { return m_pTableMap; }

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/UITools.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/UITools.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/UITools.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/UITools.hxx Mon Aug  1 04:31:52 2016
@@ -147,7 +147,7 @@ namespace dbaui
 						sal_Int32 _nKeyType);
 
 	/** fills a map and a vector with localized type names
-		@param	_rxConnection	the connection to acces the metadata
+		@param	_rxConnection	the connection to access the metadata
 		@param	_rsTypeNames	a list of localized type names separated with ';'
 		@param	_rTypeInfoMap	the filled map with the type names
 		@param 	_rTypeInfoIters	the vector filled with map iterators

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/datasourcemap.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/datasourcemap.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/datasourcemap.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/inc/datasourcemap.hxx Mon Aug  1 04:31:52 2016
@@ -190,7 +190,7 @@ namespace dbaui
 		::rtl::OUString	getRealName() const;
 		/// check if the datasource should is about to be renamed (which means the original name does not equal the real name
 		sal_Bool		isRenamed() const { return !getRealName().equals(getOriginalName()); }
-		/// get the key used to acces the object in the data source map
+		/// get the key used to access the object in the data source map
 		sal_Int32		getAccessKey() const { return m_nAccessKey; }
 
 		/// return the datasource the object represents

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/querydesign/querycontroller.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/querydesign/querycontroller.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/querydesign/querycontroller.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/querydesign/querycontroller.cxx Mon Aug  1 04:31:52 2016
@@ -1160,7 +1160,7 @@ void SAL_CALL OQueryController::disposin
 	if ( getContainer() && Source.Source.is() )
 	{
 		if ( Source.Source == m_aCurrentFrame.getFrame() )
-		{	// our frame is beeing disposed -> close the preview window (if we have one)
+		{	// our frame is being disposed -> close the preview window (if we have one)
             Reference< XFrame > xPreviewFrame( getContainer()->getPreviewFrame() );
 			::comphelper::disposeComponent( xPreviewFrame );
 		}

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/uno/copytablewizard.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/uno/copytablewizard.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/uno/copytablewizard.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/ui/uno/copytablewizard.cxx Mon Aug  1 04:31:52 2016
@@ -633,7 +633,7 @@ namespace
         with it. This doocument may have an InteractionHandler used while loading it.
 
         @throws RuntimeException
-            if it occures during invoking any of the data source's methods, or if any of the involved
+            if it occurs during invoking any of the data source's methods, or if any of the involved
             components violates its contract by not providing the required interfaces
     */
     InteractionHandler lcl_getInteractionHandler_throw( const Reference< XDataSource >& _rxDataSource, const InteractionHandler& _rFallback )
@@ -662,7 +662,7 @@ namespace
         is examined for an interaction handler. Else, <NULL/> is returned.
 
         @throws RuntimeException
-            if it occures during invoking any of the data source's methods, or if any of the involved
+            if it occurs during invoking any of the data source's methods, or if any of the involved
             components violates its contract by not providing the required interfaces
     */
     InteractionHandler lcl_getInteractionHandler_throw( const Reference< XConnection >& _rxConnection, const InteractionHandler& _rFallback )
--- openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/locale.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/locale.hxx Mon Aug  1 04:31:52 2016
@@ -51,7 +51,7 @@ namespace comphelper{
 
     @descr  This Locale class can be used to:
             - provide the different parts of a Locale (Language, Country, Variant)
-            - converting it from/to ISO formated string values (like e.g. "en-US")
+            - converting it from/to ISO formatted string values (like e.g. "en-US")
             - provide some predefined (static) Locale objects
  */
 class COMPHELPER_DLLPUBLIC Locale
@@ -61,13 +61,13 @@ class COMPHELPER_DLLPUBLIC Locale
 
     public:
     
         /** @short separates LANGUAGE and COUNTRY part of an ISO formated Locale. */
         static const sal_Unicode SEPERATOR_LC;
         
         /** @short separates COUNTRY and VARIANT part of an ISO formated Locale. */
         static const sal_Unicode SEPERATOR_CV;
         
         /** @short separates COUNTRY and VARIANT part of an ISO formated Locale.
             @descr Its true for some linux derivates only :-( */
         static const sal_Unicode SEPERATOR_CV_LINUX;
         
@@ -168,18 +168,18 @@ class COMPHELPER_DLLPUBLIC Locale
         //---------------------------------------
         /** @short  needed by outside users!
         
-            @descr  Otherwise it wouldnt be possible to use
+            @descr  Otherwise it wouldn't be possible to use
                     any instance of such Locale static ...
          */
         Locale();
         
         //---------------------------------------
         /** @short      construct a Locale from an ISO formated string value.
         
             @seealso    fromISO()
             
             @param      sISO
-                        an ISO formated string value, which can be parsed and
+                        an ISO formatted string value, which can be parsed and
                         tokenized into a Lamnguage, Country and Variant part.
                         
             @throw      MalFormedLocaleException
@@ -282,7 +282,7 @@ class COMPHELPER_DLLPUBLIC Locale
             @seealso    Locale(const ::rtl::OUString& sISO)
             
             @param      sISO
-                        an ISO formated string value, which can be parsed and
+                        an ISO formatted string value, which can be parsed and
                         tokenized into a Lamnguage, Country and Variant part.
                         e.g. "en-US" or "en-US_WIN"
                         
@@ -293,13 +293,13 @@ class COMPHELPER_DLLPUBLIC Locale
             throw(MalFormedLocaleException);
         
         //---------------------------------------
         /** @short  converts this Locale to an ISO formated string value.
         
             @descr  The different parts of this Locale will be assempled
                     e.g. to "en-US" or "en-US_WIN"
                     
             @return [string]
-                    the ISO formated string.
+                    the ISO formatted string.
           */
         ::rtl::OUString toISO() const;
 
@@ -323,7 +323,7 @@ class COMPHELPER_DLLPUBLIC Locale
                     uses the same language.
         
             @descr  The Country and Variant parts of a Locale
-                    wont be checked here.
+                    won't be checked here.
                     
             @return [boolean]
                     TRUE if both objects uses the same
@@ -363,7 +363,7 @@ class COMPHELPER_DLLPUBLIC Locale
             
             @param      lISOList
                         the list of possible Locales
-                        (as formated ISO strings).
+                        (as formatted ISO strings).
                         
             @param      sReferenceISO
                         the reference Locale, which should be searched
@@ -376,7 +376,7 @@ class COMPHELPER_DLLPUBLIC Locale
                         to the end of the list.                        
                         
             @throw      [MalFormedLocaleException]
-                        if at least one ISO formated string couldnt
+                        if at least one ISO formatted string couldnt
                         be converted to a valid Locale Object.
          */
         static ::std::vector< ::rtl::OUString >::const_iterator getFallback(const ::std::vector< ::rtl::OUString >& lISOList     ,
@@ -61,13 +61,13 @@ class COMPHELPER_DLLPUBLIC Locale
     public:
     
-        /** @short separates LANGUAGE and COUNTRY part of an ISO formated Locale. */
+        /** @short separates LANGUAGE and COUNTRY part of an ISO formatted Locale. */
         static const sal_Unicode SEPERATOR_LC;
         
@@ -61,13 +61,13 @@ class COMPHELPER_DLLPUBLIC Locale
         static const sal_Unicode SEPERATOR_LC;
         
-        /** @short separates COUNTRY and VARIANT part of an ISO formated Locale. */
+        /** @short separates COUNTRY and VARIANT part of an ISO formatted Locale. */
         static const sal_Unicode SEPERATOR_CV;
         
@@ -61,13 +61,13 @@ class COMPHELPER_DLLPUBLIC Locale
         static const sal_Unicode SEPERATOR_CV;
         
-        /** @short separates COUNTRY and VARIANT part of an ISO formated Locale.
+        /** @short separates COUNTRY and VARIANT part of an ISO formatted Locale.
             @descr Its true for some linux derivates only :-( */
         static const sal_Unicode SEPERATOR_CV_LINUX;
@@ -168,18 +168,18 @@ class COMPHELPER_DLLPUBLIC Locale
         
         //---------------------------------------
-        /** @short      construct a Locale from an ISO formated string value.
+        /** @short      construct a Locale from an ISO formatted string value.
         
             @seealso    fromISO()
@@ -293,13 +293,13 @@ class COMPHELPER_DLLPUBLIC Locale
         
         //---------------------------------------
-        /** @short  converts this Locale to an ISO formated string value.
+        /** @short  converts this Locale to an ISO formatted string value.
         
             @descr  The different parts of this Locale will be assempled

Modified: openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/numberedcollection.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/comphelper/inc/comphelper/numberedcollection.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/inc/definitioncontainer.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/inc/definitioncontainer.hxx Mon Aug  1 04:31:52 2016
@@ -272,7 +272,7 @@ protected:
 	virtual ::com::sun::star::uno::Reference< ::com::sun::star::ucb::XContent >
 				implGetByName(const ::rtl::OUString& _rName, sal_Bool _bCreateIfNecessary) throw (::com::sun::star::container::NoSuchElementException);
 
 	/** quickly checks if there already is an element with a given name. No access to the configuration occures, i.e.
 		if there is such an object which is not already loaded, it won't be loaded now.
 		@param		_rName		the object name to check
 		@return					sal_True if there already exists such an object
@@ -350,7 +350,7 @@ private:
             if the object already exists in the container, or another object with the same name
             already exists
         @throws WrappedTargetException
-            if another error occures which prevents insertion of the object into the container
+            if another error occurs which prevents insertion of the object into the container
 	*/
 	void approveNewObject(
             const ::rtl::OUString& _sName,
@@ -272,7 +272,7 @@ protected:
 				implGetByName(const ::rtl::OUString& _rName, sal_Bool _bCreateIfNecessary) throw (::com::sun::star::container::NoSuchElementException);
 
-	/** quickly checks if there already is an element with a given name. No access to the configuration occures, i.e.
+	/** quickly checks if there already is an element with a given name. No access to the configuration occurs, i.e.
 		if there is such an object which is not already loaded, it won't be loaded now.
 		@param		_rName		the object name to check

Modified: openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/recovery/dbdocrecovery.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/dbaccess/source/core/recovery/dbdocrecovery.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================